@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.86';
+  $Devel::PatchPerl::VERSION = '0.88';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -290,6 +290,13 @@ sub _run_or_die
   die unless system( @_ ) == 0;
 }
 
+sub determine_version {
+  my $src = shift;
+  $src = shift if eval { $src->isa(__PACKAGE__) };
+  $src = '.' unless $src;
+  _determine_version($src);
+}
+
 sub _determine_version {
   my ($source) = @_;
   my $patchlevel_h = File::Spec->catfile($source, 'patchlevel.h');
@@ -308,8 +315,11 @@ sub _determine_version {
     if ( my @wotsits = grep { defined $defines{$_} } qw(PERL_REVISION PERL_VERSION PERL_SUBVERSION) ) {
       $version = join '.', map { $defines{$_} } @wotsits;
     }
+    elsif ( my @watsits = grep { defined $defines{$_} } qw(PATCHLEVEL SUBVERSION) ) {
+      $version = sprintf '5.%03d_%02d', map { $defines{$_} } @watsits;
+    }
     else {
-      $version = sprintf '5.%03d_%02d', map { $defines{$_} } qw(PATCHLEVEL SUBVERSION);
+      return;
     }
   }
   return $version;
@@ -2124,7 +2134,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.86
+version 0.88
 
 =head1 SYNOPSIS
 
@@ -2158,6 +2168,14 @@ C<perl> version from the specified path.
 If you don't supply the path to unwrapped perl source, it will assume the
 current working directory.
 
+=item C<determine_version>
+
+Takes one optional parameter, the path to unwrapped perl source. It returns the perl version
+of the source code at the given location. It returns undef on error.
+
+If you don't supply the path to unwrapped perl source, it will assume the
+current working directory.
+
 =back
 
 =head1 PLUGIN SYSTEM
